#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2008-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    runner.py
# @author  Michael Behrisch
# @author  Jakob Erdmann
# @author  Daniel Krajzewicz
# @date    2011-03-04


from __future__ import print_function
from __future__ import absolute_import
import os
import sys
if "SUMO_HOME" in os.environ:
    sys.path.append(os.path.join(os.environ['SUMO_HOME'], 'tools'))
import traci  # noqa
import sumolib  # noqa
import simpla  # noqa
from simpla import SimplaException  # noqa

binary = 'sumo-gui'
if 'nogui' in sys.argv:
    binary = 'sumo'

traci.start([sumolib.checkBinary(binary),
            '-c', 'osm.sumocfg',
            '--collision.mingap-factor', '0',
            '--step-length', '0.5',
            '--default.action-step-length', '0.5',
            '--step-method.ballistic', 
            '--time-to-teleport', '300',
            '--emission-output', 'emission.out.xml',
            '--emissions.volumetric-fuel',
            '--emission-output.step-scaled',
            '--summary', 'summary.out.xml',
            '--fcd-output', 'fcd.out.xml',
            '--fcd-output.max-leader-distance', '1000',
            '--vehroutes', 'vehroute.out.xml',
            '--personroute-output', 'personroute.out.xml',
            '--vehroute-output.cost',
            '--vehroute-output.route-length',
            '--vehroute-output.write-unfinished',
            '--parking.maneuver', 'true',
            '--tripinfo-output', 'tripinfo.out.xml',
            '--device.battery.track-fuel',
            '--statistic-output', 'statistic.out.xml',
            '--collision-output', 'collisions.out.xml',
            '--stop-output', 'stop.out.xml',
            '--verbose',
            '--duration-log.statistics', 'TRUE',
            '--log', 'logfile.out.xml',
            '-H'])

simpla.load("simpla.cfg.xml")

while traci.simulation.getMinExpectedNumber() > 0:
    traci.simulationStep()

traci.close()
